========
Glossary
========

.. glossary::
    :sorted:

    icalendar
        This Python package, with a lower-case "c", used for parsing and generating :term:`iCalendar` files following the standard in :rfc:`5545`.

    iCalendar
        The RFC called Internet Calendaring and Scheduling Core Object Specification (iCalendar), with an upper-case "C".
        Files that follow the iCalendar specification are called iCalendar files.

    Vale
        `Vale <https://vale.sh/>`_ is an open-source, command-line tool that helps maintain a consistent and on-brand voice in documentation.
        icalendar documentation uses it to check spelling, English grammar and syntax, and style guides.
